@@ -62,10 +62,9 @@ sub skip_combinations {
   sub ipv6_ok() {
     use Socket;
     return 0 unless socket my $sock, PF_INET6, SOCK_STREAM, getprotobyname('tcp');
-    $!="";
     # eval{}, if there's no Socket::sockaddr_in6 at all, old Perl installation
-    eval { bind $sock, sockaddr_in6($::baseport, Socket::IN6ADDR_LOOPBACK) };
-    return $@ eq "" && $! eq ""
+    eval { connect $sock, sockaddr_in6(7, Socket::IN6ADDR_LOOPBACK) };
+    return $@ eq "";
   }
   $skip{'include/check_ipv6.inc'} = 'No IPv6' unless ipv6_ok();
 
@@ -73,15 +72,10 @@ sub skip_combinations {
     unless $::mysqld_variables{'version-ssl-library'} =~ /OpenSSL (\S+)/
        and $1 ge "1.0.1d";
 
-
   $skip{'t/ssl_7937.combinations'} = [ 'x509v3' ]
     unless $::mysqld_variables{'version-ssl-library'} =~ /OpenSSL (\S+)/
        and $1 ge "1.0.2";
 
-  $skip{'t/ssl_verify_ip.test'} = 'x509v3 support required'
-    unless $::mysqld_variables{'version-ssl-library'} =~ /OpenSSL (\S+)/
-       and $1 ge "1.0.2";
-
   %skip;
 }
 
